Documentation
¶
Overview ¶
Package help implements a help bubble which can be used to display help information such as keymaps.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
Viewport viewport.Model
Entries []Entry
Title string
TitleColor TitleColor
ViewportDisabled bool
}
Model represents the properties of a help bubble.
func New ¶
func New( title string, titleColor TitleColor, entries []Entry, ) Model
New creates a new instance of a help bubble.
func (*Model) GotoBottom ¶
func (m *Model) GotoBottom()
GotoBottom jumps to the bottom of the viewport.
func (*Model) SetTitleColor ¶
func (m *Model) SetTitleColor(color TitleColor)
SetTitleColor sets the color of the title.
func (*Model) SetViewportDisabled ¶
SetViewportDisabled toggles the state of the viewport.
type TitleColor ¶
type TitleColor struct {
Background lipgloss.AdaptiveColor
Foreground lipgloss.AdaptiveColor
}
Click to show internal directories.
Click to hide internal directories.